==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/sr@latin.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Skladište nije dostupno",
    "Storage invalid" : "Neispravno skladište",
    "Unknown error" : "Nepoznata greška",
    "Could not move %s - File with this name already exists" : "Ne mogu da premestim %s – fajl sa ovim nazivom već postoji",
    "Could not move %s" : "Ne mogu da premestim %s",
    "Permission denied" : "Pristup odbijen",
    "The target folder has been moved or deleted." : "Odredišna fascikla je premeštena ili obrisana.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Naziv %s se već koristi u fascikli %s. Odredite drugi naziv.",
    "Error when creating the file" : "Greška pri stvaranju fajla",
    "Error when creating the folder" : "Greška pri stvaranju fajla",
    "Unable to set upload directory." : "Ne mogu da postavim direktorijum za otpremanje.",
    "Invalid Token" : "Neispravan token",
    "No file was uploaded. Unknown error" : "Nijedan fajl nije otpremljen. Nepoznata greška",
    "There is no error, the file uploaded with success" : "Nema greške, fajl je uspešno otpremljen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Otpremani fajl prevazilazi smernicu upload_max_filesize u fajlu php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremani fajl prevazilazi smernicu MAX_FILE_SIZE koja je navedena u HTML obrascu",
    "The uploaded file was only partially uploaded" : "Otpremani fajl je samo delimično otpremljen",
    "No file was uploaded" : "Ništa nije otpremljeno",
    "Missing a temporary folder" : "Nedostaje privremena fascikla",
    "Failed to write to disk" : "Ne mogu da pišem na disk",
    "Not enough storage available" : "Nema dovoljno prostora",
    "Upload failed. Could not find uploaded file" : "Neuspešno otpremanje. Ne mogu da nađem otpremljeni fajl",
    "Upload failed. Could not get file info." : "Neuspešno otpremanje. Ne mogu da dobijem podatke o fajlu.",
    "Invalid directory." : "Neispravna fascikla.",
    "Files" : "Fajlovi",
    "All files" : "Svi fajlovi",
    "Favorites" : "Omiljeni",
    "Home" : "Početna",
    "Close" : "Zatvori",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ne mogu da otpremim {filename} jer je to direktorijum ili ima 0 bajtova",
    "Total file size {size1} exceeds upload limit {size2}" : "Veličina {size1} prevazilazi ograničenje za otpremanje od {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nema prostora. Otpremate {size1} ali samo {size2} je preostalo",
    "Upload cancelled." : "Otpremanje je otkazano.",
    "Could not get result from server." : "Ne mogu da dobijem rezultat sa servera.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Otpremanje fajla je u toku. Ako sada napustite stranicu, otkazaćete otpremanje.",
    "Download" : "Preuzmi",
    "Rename" : "Preimenuj",
    "Delete" : "Obriši",
    "Details" : "Detaljnije",
    "Select" : "Izaberi",
    "Pending" : "Na čekanju",
    "Unable to determine date" : "Ne mogu da odredim datum",
    "Error moving file." : "Greška pri premeštanju fajla.",
    "Error moving file" : "Greška pri premeštanju fajla",
    "Error" : "Greška",
    "{new_name} already exists" : "{new_name} već postoji",
    "Could not rename file" : "Ne mogu da preimenujem fajl",
    "Could not create file" : "Ne mogu da stvorim fajl",
    "Could not create folder" : "Ne mogu da stvorim fasciklu",
    "Error deleting file." : "Greška pri brisanju fajla.",
    "No entries in this folder match '{filter}'" : "U ovoj fascikli ništa se ne poklapa sa '{filter}'",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Izmenjen",
    "_%n folder_::_%n folders_" : ["%n fascikla","%n fascikle","%n fascikli"],
    "_%n file_::_%n files_" : ["%n fajl","%n fajla","%n fajlova"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Nemate dozvole da ovde otpremate ili stvarate fajlove",
    "_Uploading %n file_::_Uploading %n files_" : ["Otpremam %n fajl","Otpremam %n fajla","Otpremam %n fajlova"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" nije ispravan naziv fajla.",
    "File name cannot be empty." : "Naziv fajla ne može biti prazan.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše skladište je puno. Fajlovi više ne mogu biti ažurirani ni sinhronizovani!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše skladište je skoro puno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se poklapa sa '{filter}'","se poklapaju sa '{filter}'","se poklapa sa '{filter}'"],
    "Favorited" : "Omiljeno",
    "Favorite" : "Omiljeni",
    "Upload" : "Otpremi",
    "Text file" : "tekstualni fajl",
    "Folder" : "fascikla",
    "New folder" : "Nova fascikla",
    "An error occurred while trying to update the tags" : "Došlo je do greške pri pokušaju ažuriranja oznaka",
    "A new file or folder has been <strong>created</strong>" : "Novi fajl ili fascikla su <strong>napravljeni</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fajl ili fascikla su <strong>izmenjeni</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ograniči obaveštenja o stvaranju i izmenama na <strong>omiljene fajlove</strong> <em>(samo u zapisniku)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Fajl ili fascikla su <strong>obrisani</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fajl ili fascikla su <strong>vraćeni</strong>",
    "You created %1$s" : "Napravili ste %1$s",
    "%2$s created %1$s" : "%2$s napravi %1$s",
    "%1$s was created in a public folder" : "%1$s je napravljen u javnoj fascikli",
    "You changed %1$s" : "Izmenili ste %1$s",
    "%2$s changed %1$s" : "%2$s izmeni %1$s",
    "You deleted %1$s" : "Obrisali ste %1$s",
    "%2$s deleted %1$s" : "%2$s obrisa %1$s",
    "You restored %1$s" : "Vratili ste %1$s",
    "%2$s restored %1$s" : "%2$s povrati %1$s",
    "%s could not be renamed as it has been deleted" : "%s se ne može preimenovati jer je obrisan",
    "%s could not be renamed" : "%s se ne može preimenovati",
    "Upload (max. %s)" : "Otpremanje (maks. %s)",
    "File handling" : "Rukovanje fajlovima",
    "Maximum upload size" : "Najveća veličina otpremanja",
    "max. possible: " : "najviše moguće:",
    "Save" : "Sačuvaj",
    "Can not be edited from here due to insufficient permissions." : "Ne može da se menja odavde zbog nedostatka dozvola.",
    "Settings" : "Postavke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Koristite ovu adresu da <a href=\"%s\" target=\"_blank\"> pristupite fajlovima preko WebDAV-a</a>",
    "Cancel upload" : "Otkaži otpremanje",
    "No files in here" : "Ovde nema fajlova",
    "Upload some content or sync with your devices!" : "Otpremite neki sadržaj ili sinhronizujte sa vašim uređajima!",
    "No entries found in this folder" : "Nema ničega u ovoj fascikli",
    "Select all" : "Označi sve",
    "Upload too large" : "Otpremanje je preveliko",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fajlovi koje želite da otpremite prevazilaze ograničenje otpremanja na ovom serveru.",
    "Files are being scanned, please wait." : "Skeniram fajlove, sačekajte.",
    "Currently scanning" : "Trenutno skeniram",
    "No favorites" : "Nema omiljenih",
    "Files and folders you mark as favorite will show up here" : "Fajlovi i fascikle koje obeležite kao omiljene pojaviće se ovde"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/sr@latin.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Skladište nije dostupno",
    "Storage invalid" : "Neispravno skladište",
    "Unknown error" : "Nepoznata greška",
    "Unable to set upload directory." : "Ne mogu da postavim direktorijum za otpremanje.",
    "Invalid Token" : "Neispravan token",
    "No file was uploaded. Unknown error" : "Nijedan fajl nije otpremljen. Nepoznata greška",
    "There is no error, the file uploaded with success" : "Nema greške, fajl je uspešno otpremljen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Otpremani fajl prevazilazi smernicu upload_max_filesize u fajlu php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremani fajl prevazilazi smernicu MAX_FILE_SIZE koja je navedena u HTML obrascu",
    "The uploaded file was only partially uploaded" : "Otpremani fajl je samo delimično otpremljen",
    "No file was uploaded" : "Ništa nije otpremljeno",
    "Missing a temporary folder" : "Nedostaje privremena fascikla",
    "Failed to write to disk" : "Ne mogu da pišem na disk",
    "Not enough storage available" : "Nema dovoljno prostora",
    "The target folder has been moved or deleted." : "Odredišna fascikla je premeštena ili obrisana.",
    "Upload failed. Could not find uploaded file" : "Neuspešno otpremanje. Ne mogu da nađem otpremljeni fajl",
    "Upload failed. Could not get file info." : "Neuspešno otpremanje. Ne mogu da dobijem podatke o fajlu.",
    "Invalid directory." : "Neispravna fascikla.",
    "Files" : "Fajlovi",
    "All files" : "Svi fajlovi",
    "Favorites" : "Omiljeni",
    "Home" : "Početna",
    "Close" : "Zatvori",
    "Upload cancelled." : "Otpremanje je otkazano.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ne mogu da otpremim {filename} jer je to direktorijum ili ima 0 bajtova",
    "Total file size {size1} exceeds upload limit {size2}" : "Veličina {size1} prevazilazi ograničenje za otpremanje od {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nema prostora. Otpremate {size1} ali samo {size2} je preostalo",
    "Could not get result from server." : "Ne mogu da dobijem rezultat sa servera.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Otpremanje fajla je u toku. Ako sada napustite stranicu, otkazaćete otpremanje.",
    "Download" : "Preuzmi",
    "Rename" : "Preimenuj",
    "Delete" : "Obriši",
    "Disconnect storage" : "Isključi skladište",
    "Unshare" : "Ne deli",
    "Details" : "Detaljnije",
    "Select" : "Izaberi",
    "Pending" : "Na čekanju",
    "Unable to determine date" : "Ne mogu da odredim datum",
    "No entries in this folder match '{filter}'" : "U ovoj fascikli ništa se ne poklapa sa '{filter}'",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Izmenjen",
    "_%n folder_::_%n folders_" : ["%n fascikla","%n fascikle","%n fascikli"],
    "_%n file_::_%n files_" : ["%n fajl","%n fajla","%n fajlova"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Nemate dozvole da ovde otpremate ili stvarate fajlove",
    "_Uploading %n file_::_Uploading %n files_" : ["Otpremam %n fajl","Otpremam %n fajla","Otpremam %n fajlova"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" nije ispravan naziv fajla.",
    "File name cannot be empty." : "Naziv fajla ne može biti prazan.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše skladište je puno. Fajlovi više ne mogu biti ažurirani ni sinhronizovani!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše skladište je skoro puno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se poklapa sa '{filter}'","se poklapaju sa '{filter}'","se poklapa sa '{filter}'"],
    "Favorited" : "Omiljeno",
    "Favorite" : "Omiljeni",
    "Folder" : "fascikla",
    "New folder" : "Nova fascikla",
    "Upload" : "Otpremi",
    "An error occurred while trying to update the tags" : "Došlo je do greške pri pokušaju ažuriranja oznaka",
    "A new file or folder has been <strong>created</strong>" : "Novi fajl ili fascikla su <strong>napravljeni</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fajl ili fascikla su <strong>izmenjeni</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ograniči obaveštenja o stvaranju i izmenama na <strong>omiljene fajlove</strong> <em>(samo u zapisniku)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Fajl ili fascikla su <strong>obrisani</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fajl ili fascikla su <strong>vraćeni</strong>",
    "You created %1$s" : "Napravili ste %1$s",
    "%2$s created %1$s" : "%2$s napravi %1$s",
    "%1$s was created in a public folder" : "%1$s je napravljen u javnoj fascikli",
    "You changed %1$s" : "Izmenili ste %1$s",
    "%2$s changed %1$s" : "%2$s izmeni %1$s",
    "You deleted %1$s" : "Obrisali ste %1$s",
    "%2$s deleted %1$s" : "%2$s obrisa %1$s",
    "You restored %1$s" : "Vratili ste %1$s",
    "%2$s restored %1$s" : "%2$s povrati %1$s",
    "Upload (max. %s)" : "Otpremanje (maks. %s)",
    "File handling" : "Rukovanje fajlovima",
    "Maximum upload size" : "Najveća veličina otpremanja",
    "max. possible: " : "najviše moguće:",
    "Save" : "Sačuvaj",
    "Settings" : "Postavke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Koristite ovu adresu da <a href=\"%s\" target=\"_blank\"> pristupite fajlovima preko WebDAV-a</a>",
    "Cancel upload" : "Otkaži otpremanje",
    "No files in here" : "Ovde nema fajlova",
    "Upload some content or sync with your devices!" : "Otpremite neki sadržaj ili sinhronizujte sa vašim uređajima!",
    "No entries found in this folder" : "Nema ničega u ovoj fascikli",
    "Select all" : "Označi sve",
    "Upload too large" : "Otpremanje je preveliko",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fajlovi koje želite da otpremite prevazilaze ograničenje otpremanja na ovom serveru.",
    "No favorites" : "Nema omiljenih",
    "Files and folders you mark as favorite will show up here" : "Fajlovi i fascikle koje obeležite kao omiljene pojaviće se ovde",
    "Text file" : "tekstualni fajl"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
